@@ -105,6 +105,23 @@ class MedicalBookRequest(BaseModel):
     activity_keys: list = Field(description="Ключи типов деятельности")
 
 
+class UserExtended(ClientInfo):
+    fio: str = Field(description="ФИО")
+    birth_date: str = Field(description="Дата рождения")
+
+
+class MedicalBookSearchResponseOther(BaseModel):
+    id: int = Field(description="Id ЛМК в гигтесте")
+    number: str = Field(description="Номер ЛМК")
+    regnum: str = Field(description="Рег. номер ЛМК")
+    date: str = Field(description="Дата выдачи ЛМК")
+    next_education_date: str = Field(description="Дата следующей аттестации")
+    status: str = Field(description="Статус ЛМК: new, accepted, returned, completed")
+    activity_names: list = Field(description="Тип деятельности")
+    user: UserExtended = Field(description="Гигтест клиент")
+    medical_direction_ids: list = Field(description="Гигтест id мед. направлений")
+
+
 class User(BaseModel):
     fio: str
 
@@ -177,6 +194,16 @@ class MedicineCreateOrUpdateResponseResults(BaseModel):
     id: int = Field(description="Id медобследования в гигтест")
 
 
+class MedicineCreateOrUpdateResponseResultsExtended(
+    MedicineCreateOrUpdateResponseResults
+):
+    medical_research_name: str = Field(description="Название услуги")
+    date_med_result: str = Field(description="Дата обследования")
+    medical_research_result: int = Field(
+        description="Результат обследования. Предположительно 1 - нет противопоказаний"
+    )
+
+
 class MedicineCreateResponse(BaseModel):
     id: int = Field(description="Id медобследования в гигтест")
     results: List[MedicineCreateOrUpdateResponseResults] = Field(
@@ -184,6 +211,12 @@ class MedicineCreateResponse(BaseModel):
     )
 
 
+class MedicineCreateResponseExtended(MedicineCreateResponse):
+    results: List[MedicineCreateOrUpdateResponseResultsExtended] = Field(
+        description="Исследования"
+    )
+
+
 class MedicineUpdateResponse(BaseModel):
     results: List[MedicineCreateOrUpdateResponseResults] = Field(
         description="Исследования"
@@ -210,6 +243,7 @@ class GigtestService:
         self._create_or_update_client_url = "/api/v2/users"
         # МЕДКНИЖКА
         self._medbook_url = "/api/v2/medical-books"
+        self._medbook_url_search = "/api/v2/medical-books/search"
         # АТТЕСТАЦИЯ
         self._attestation_url = "/api/v2/protocols"
         # МЕДИЦИНА
@@ -296,6 +330,16 @@ class GigtestService:
         )
 
     # МЕДКНИЖКИ
+    def search_medbook_when_other_department(
+        self, medbook_number: int
+    ) -> SDKResponse[MedicalBookSearchResponseOther]:
+        return self._client.get(
+            self._full_url(self._medbook_url_search),
+            MedicalBookSearchResponseOther,
+            params={"number": medbook_number},
+            timeout=COMMON_GIGTEST_TIMEOUT,
+        )
+
     def search_medbook(
         self, medbook_number: int
     ) -> SDKResponse[List[MedicalBookSearchResponse]]:
@@ -360,13 +404,14 @@ class GigtestService:
         )
 
     # МЕДИЦИНА
-    # этот метод не используется. Для проверки
-    def get_med_direction(self, gigtest_med_direction_id: int) -> SDKResponse[Empty]:
+    def get_med_direction(
+        self, gigtest_med_direction_id: int
+    ) -> SDKResponse[MedicineCreateResponseExtended]:
         return self._client.get(
             self._full_url(
                 self._create_update_medicine_url + "/" + str(gigtest_med_direction_id)
             ),
-            Empty,
+            MedicineCreateResponseExtended,
             timeout=COMMON_GIGTEST_TIMEOUT,
         )
 
@@ -403,6 +448,7 @@ class GigtestService:
             timeout=LONG_GIGTEST_TIMEOUT,
         )
 
+    # TODO выше метод get_med_direction объединить с этим, проверив апи
     def search_med_direction(
         self, gigtest_med_direction_id: int
     ) -> SDKResponse[MedicineUpdateResponse]:
